local modUtil = require "merk_modutil_1_1"
require "stringutil"

local options_taoos_y = {
	taoos_y_fake = { type = "boolean", default = false, name = _("Fake Version"), description = _("option_taoos_y_desc"), image = "res/textures/ui/models_small/vehicle/waggon/taoos_y_fake_db_cargo.tga" },	
}

local files = {
	"taoos_y_db_ag.mdl",
	"taoos_y_db_cargo.mdl",
	"taoos_y_railion.mdl",	
}

local function isValidFile(fileName)
	for i = 1, #files do
		if string.ends (fileName, files[i]) then
			return true
		end
	end
	
	return false
end

local function vehicleHandler(fileName, data)
	--[[ Hilfsfunktion(en) Anfang]]

	local function findOnGameCargoTypes ( entry )
		for i = 1, #game.config.cargotypes do
			if entry == game.config.cargotypes[i].id then
				return true
			end
		end
		
		return false
	end
	
	local function doIt ( capacities )
		local result = { }
		for i = 1, #capacities do
			if findOnGameCargoTypes (capacities[i].type) then
				result[#result + 1] = capacities[i]
			end
		end
		
		-- Sind keine Güterarten mehr gültig, so setzen wir 6 beliebige, vorhandene Güterarten ein.
		if #result == 0 then
			for i = 1, #game.config.cargotypes do
				if game.config.cargotypes[i].id ~= "PASSENGERS" then
					result[#result + 1] = {
						type = game.config.cargotypes[i].id,
						capacity = 32,
					}
					if #result == 6 then
						break
					end
				end
			end
		end
		return result
	end
		--[[ Hilfsfunktion(en) Ende]]
		
	if isValidFile (fileName) and data.metadata and data.metadata.transportVehicle and data.metadata.transportVehicle.capacities then
		data.metadata.transportVehicle.capacities = doIt (data.metadata.transportVehicle.capacities)
	end
	return data
end

function data()
return {
	info = {
		minorVersion = 3,
		severityAdd = "NONE",
		severityRemove = "WARNING",
		name = _("Taoos-y 894"),
		description = _("info_taoos_y_desc"),
		tags = { "Europe", "Wagon", },
		authors = {
			{
				name = "Kaleut1988",
				role = "CREATOR",
				tfnetId = 22532,
			},
			{
				name = "EAT1963",
				role = "CO_CREATOR",
				text = "cargo script",
				tfnetId = 19725,				
			},
			{
				name = "baubus",
				role = "CO_CREATOR",
				text = "soundset",
				tfnetId = 18332,				
			},			
		},
		url = "https://www.transportfever.net/filebase/index.php/Entry/3028-Taoos-y-894/",
		tfnetId = 3028,
		steamId = 925875951,  
		dependencies = {},
		visible = true
	},
	settings = options_taoos_y,
		
	runFn = function(settings)
		modUtil.initialize("kaleut_taoos_y", options_taoos_y, files)
		addModifier( "loadModel", vehicleHandler )
		local settings = modUtil.userSettings.get("kaleut_taoos_y")	
		if not settings.taoos_y_fake then
			modUtil.vehicles.hideObject("vehicle/waggon/taoos_y_fake_db_ag.mdl")
			modUtil.vehicles.hideObject("vehicle/waggon/taoos_y_fake_db_cargo.mdl")
			modUtil.vehicles.hideObject("vehicle/waggon/taoos_y_fake_railion.mdl")			
		end		
		
	end
}
end
